@@ -15,7 +15,7 @@ server <- "AQSDatamartAPI"
 #'           called directly by the end user or to be called outside of RAQSAPI.
 #'          variables will remain unchanged.
 #' @importFrom lubridate is.Date
-#' @importFrom rlang abort call_frame format_error_bullets
+#' @importFrom rlang abort format_error_bullets call_name
 #' @importFrom dplyr between
 #' @importFrom glue glue
 #' @importFrom magrittr `%<>%`
@@ -248,7 +248,8 @@ checkaqsparams <- function(...)
   }
   if (error)
     {
-      callingfunction <- rlang::call_frame(n = 2)$fn_name
+      callingfunction <- rlang::call_name(sys.call(sys.parent(2)))
+      #callingfunction <- rlang::call_frame(n = 2)$fn_name
       if (is.null(callingfunction)) callingfunction <- "Unknown Environment"
       callingfunction <- glue(" in: {callingfunction}")
       c('i' = callingfunction, errmessage) %>% abort
@@ -364,7 +365,7 @@ aqs_ratelimit <- function(waittime=5L)
 #' @importFrom dplyr mutate select arrange
 #' @importFrom lubridate ymd_hm
 #' @importFrom glue glue
-#' @importFrom rlang .data
+#' @importFrom rlang .data is_empty
 #' @importFrom tibble as_tibble
 #' @importFrom httr GET http_type content http_error status_code modify_url
 #'               user_agent message_for_status
@@ -385,13 +386,13 @@ aqs <- function(service, filter = NA, user = NA,
   user_agent <- glue("User:{user} via RAQSAPI library for R") %>%
     httr::user_agent()
 
-   if (gtools::invalid(service) & gtools::invalid(filter))
+   if (rlang::is_empty(service) & rlang::is_empty(filter))
   {
     path <- glue::glue("/data/api/")
-  }else if (gtools::invalid(service))
+  }else if (rlang::is_empty(service))
   {
     path <- glue::glue("/data/api/")
-  }else if (gtools::invalid(filter))
+  }else if (rlang::is_empty(filter))
   {
     path <- glue::glue("/data/api/{service}")
   }else {
@@ -411,6 +412,7 @@ aqs <- function(service, filter = NA, user = NA,
                           url = path,
                           query = query
                          )
+
     AQSresult <- httr::GET(url,
                            user_agent
                            )
