@@ -353,7 +353,7 @@ aqs_removeheader <- function(AQSobject)
   if (is.null(AQSobject))
     {
     return(AQSobject)
-    } else if (class(AQSobject) == "AQS_DATAMART_APIv2")
+    } else if (class(AQSobject) %in% "AQS_DATAMART_APIv2")
              {
                 AQSobject <- AQSobject$Data
               } else if (class(AQSobject[[1]]) == "AQS_DATAMART_APIv2"
